@@ -983,6 +983,7 @@ void Proc::commonPostInit()
     Proc::mem_total = 0;
     Proc::mem_free = 0;
 
+    Proc::mem_available = -1;
     Proc::mem_buffers = 0;
     Proc::mem_cached = 0;
 
@@ -1635,8 +1636,7 @@ int Procinfo::readproc()
     //	drs		;	// data: wrong in kernel 2.6
     //	dt		;	// zero : in Kernel 2.6
     mem = resident - share;
-    // pmem = 100.0 * resident / proc->mem_total;
-    pmem = 100.0 * mem / proc->mem_total;
+    pmem = 100.0 * resident / proc->mem_total;
 
     // read /proc/PID/status check !!
     if ((buf = read_proc_file2(path, "status")) == nullptr)
@@ -1966,6 +1966,8 @@ int Proc::read_system() //
         sscanf(p, "MemTotal: %d kB\n", &mem_total);
     if ((p = strstr(buf, "MemFree:")) != nullptr)
         sscanf(p, "MemFree: %d kB\n", &mem_free);
+    if ((p = strstr(buf, "MemAvailable:")) != nullptr)
+        sscanf(p, "MemAvailable: %d kB\n", &mem_available);
     if ((p = strstr(buf, "Buffers:")) != nullptr)
         sscanf(p, "Buffers: %d kB\n", &mem_buffers);
     if ((p = strstr(buf, "Cached:")) != nullptr)
